@@ -5,14 +5,40 @@ module Temple
   #
   # @api public
   class Generator
+    include Utils
     include Mixins::CompiledDispatcher
     include Mixins::Options
 
-    define_options :capture_generator => 'StringBuffer',
-                   :buffer => '_buf'
+    define_options :save_buffer,
+                   capture_generator: 'StringBuffer',
+                   buffer: '_buf',
+                   freeze_static: RUBY_VERSION >= '2.1'
 
     def call(exp)
-      [preamble, compile(exp), postamble].join('; ')
+      [preamble, compile(exp), postamble].flatten.compact.join('; ')
+    end
+
+    def preamble
+      [save_buffer, create_buffer]
+    end
+
+    def postamble
+      [return_buffer, restore_buffer]
+    end
+
+    def save_buffer
+      "begin; #{@original_buffer = unique_name} = #{buffer} if defined?(#{buffer})" if options[:save_buffer]
+    end
+
+    def restore_buffer
+      "ensure; #{buffer} = #{@original_buffer}; end" if options[:save_buffer]
+    end
+
+    def create_buffer
+    end
+
+    def return_buffer
+      'nil'
     end
 
     def on(*exp)
@@ -28,11 +54,11 @@ module Temple
     end
 
     def on_capture(name, exp)
-      capture_generator.new(:buffer => name).call(exp)
+      capture_generator.new(buffer: name).call(exp)
     end
 
     def on_static(text)
-      concat(text.inspect)
+      concat(options[:freeze_static] ? "#{text.inspect}.freeze" : text.inspect)
     end
 
     def on_dynamic(code)
