@@ -32,14 +32,16 @@ describe Temple::Filters::Escapable do
   end
 
   it 'should have use_html_safe option' do
-    filter = Temple::Filters::Escapable.new(:use_html_safe => true)
-    filter.call([:escape, true,
-      [:static, HtmlSafeString.new("a < b")]
-    ]).should.equal [:static, "a < b"]
+    with_html_safe do
+      filter = Temple::Filters::Escapable.new(use_html_safe: true)
+      filter.call([:escape, true,
+        [:static, Temple::HTML::SafeString.new("a < b")]
+      ]).should.equal [:static, "a < b"]
+    end
   end
 
   it 'should support censoring' do
-    filter = Temple::Filters::Escapable.new(:escape_code => '(%s).gsub("Temple sucks", "Temple rocks")')
+    filter = Temple::Filters::Escapable.new(escape_code: '(%s).gsub("Temple sucks", "Temple rocks")')
     filter.call([:escape, true,
       [:static, "~~ Temple sucks ~~"]
     ]).should.equal [:static, "~~ Temple rocks ~~"]
